# Project Authors

The following people have made contributions to the project (in alphabetical
order by last name) and are considered "The Boule Developers":

* [Chris Dinneen](https://github.com/dabiged) - Unaffiliated (ORCID: [0000-0001-8615-5211](https://orcid.org/0000-0001-8615-5211))
* [Mariana Gomez](https://github.com/MGomezN) - Centro de Investigación Científica y de Educación Superior de Ensenada (CICESE), Mexico (ORCID: [0000-0002-2587-5255](https://orcid.org/0000-0002-2587-5255))
* [Lu Li](https://github.com/LL-Geo) - School of Earth Sciences, The University of Western Australia, Australia (ORCID: [0000-0001-6165-2828](https://www.orcid.org/0000-0001-6165-2828))
* [Santiago Soler](https://github.com/santisoler) - CONICET, Argentina; Instituto Geofísico Sismológico Volponi, Universidad Nacional de San Juan, Argentina (ORCID: [0000-0001-9202-5317](https://www.orcid.org/0000-0001-9202-5317))
* [Leonardo Uieda](https://github.com/leouieda) - University of Liverpool, UK (ORCID: 0000-0001-6123-9515)
